-- coffeemachine state machine

beginStateMachine()

	onEnter(function(msg)
		local damp = findChildGO("damp");
		damp.setEmitRate(0.1);
	end )
	
	onMsg("buildMenu", function(msg)
	
		if (repairMenu()) then return end
	
		-- build the pie menu
		clearPieMenu();
		
		local button;
		
		if (getChildEnable("damp")) then
			button = addPieMenuButton("pm_drinkCoffee", "use", "pourCoffee");
			button.addDescription(ACTIVITY, "drinkCoffee");
		else
			button = addPieMenuButton("pm_cookCoffee", "use", "cookCoffee");
			button.addDescription(ACTIVITY, "drinkCoffee");
		end
	end )

	onMsg("use", function(msg)
		-- get the game object server
		local gameObjectServer = getGameObjectServer();
		-- get character who initiated this action
		local character = getStateObjectFromID(msg.sender);
		
		-- check if activity is possible
		local possible, result, activity = activityPossible(character, "drinkCoffee", this);
		
		-- don't care if timeslot is not fulfilled
		if (possible or (result == TIMESLOT)) then
			-- walk to the closest action point
			--local actionPoint = character.getFreeActionPoint(this, "use");
			local actionPoint = character.getClosestFreeActionPoint(character, this, {"use1", "use2", "use3", "use4"});
			if (actionPoint) then
				-- get the walk state object
				local wso = character.walkSO;
				if (wso.walkToActionPoint(actionPoint)) then
					-- create state machine contexts
					local wsoContext = StateMachineContext();
					-- store the action point
					wsoContext.storeData("actionPointName", actionPoint.getName());
					wso.queueStateMachine("coffeemachineChar." .. msg.data, this, wsoContext);
				else
					print("no path found");
					instantAbort(character, EMOTICON_NOPATH, "emoThink")
				end
			else
				print("no action point found");
				instantAbort(character, EMOTICON_CANNOT, "emoThink")
			end
		else
			-- activity not possible
			print(msg.name .. " not possible");
			
			local emoticon;
			if (result == NO_CONDITION) then
				emoticon = conditionToEmoticon(activity.getUnfulfilledCondition());
			else
				emoticon = resultToEmoticon(result);
			end
			instantAbort(character, emoticon, "emoThink");	
		end
	end )
	
	onMsg("coolDown", function(msg)
	
		print("onMsg coolDown");
		this.setChildEnable("damp", false);

	end )
	
	
			
endStateMachine()
